@@ -23,16 +23,16 @@ import os
 import random
 import sys
 import time
+from configparser import NoOptionError, NoSectionError
 from os import environ, fdopen, path, makedirs, geteuid
 from shutil import move
 from tempfile import mkstemp
+from urllib.parse import urlparse
 
 from dogpile.cache import make_region
 from requests import Session, Response
 from requests.exceptions import ConnectionError
 from requests.status_codes import codes
-from configparser import NoOptionError, NoSectionError
-from urllib.parse import urlparse
 
 from rucio import version
 from rucio.common import exception
@@ -282,7 +282,7 @@ class BaseClient(object):
         self.__authenticate()
 
         try:
-            self.request_retries = int(config_get('client', 'request_retries'))
+            self.request_retries = config_get_int('client', 'request_retries')
         except (NoOptionError, RuntimeError):
             LOG.debug('request_retries not specified in config file. Taking default.')
         except ValueError:
@@ -364,7 +364,7 @@ class BaseClient(object):
         :param get_token: (optional) if it is called from a _get_token function.
         :param cert: (optional) if String, path to the SSL client cert file (.pem). If Tuple, (cert, key) pair.
         :param auth: (optional) auth tuple to enable Basic/Digest/Custom HTTP Auth.
-        :param verify: (optional) either a boolean, in which case it controls whether we verify the server’s TLS
+        :param verify: (optional) either a boolean, in which case it controls whether we verify the server's TLS
                        certificate, or a string, in which case it must be a path to a CA bundle to use.
         :return: the HTTP return body.
         """
@@ -627,7 +627,7 @@ class BaseClient(object):
                 # authorizing info request on behalf of the user until he/she revokes this authorization !
                 result = self._send_request(result.url, type_='POST', data=form_data)
 
-        if not result or 'result' not in locals():
+        if not result:
             self.logger.error('Cannot retrieve authentication token!')
             return False
 
@@ -794,7 +794,7 @@ class BaseClient(object):
         result = self._send_request(SAML_auth_url, type_='POST', data=userpass, verify=False)
         result = self._send_request(url, get_token=True)
 
-        if not result or 'result' not in locals():
+        if not result:
             self.logger.error('Cannot retrieve authentication token!')
             return False
 
@@ -883,7 +883,6 @@ class BaseClient(object):
             except Exception:
                 raise
 
-        # if the file exists check if the stored token is valid. If not request a new one and overwrite the file. Otherwise use the one from the file
         try:
             file_d, file_n = mkstemp(dir=self.token_path)
             with fdopen(file_d, "w") as f_token:
