@@ -15,14 +15,14 @@
 
 import copy
 import json
+import logging
 import os
 import os.path
-import socket
-
-import logging
-import time
 import random
+import socket
+import time
 
+from rucio import version
 from rucio.client.client import Client
 from rucio.common.config import config_get_int, config_get
 from rucio.common.exception import (RucioException, RSEWriteBlocked, DataIdentifierAlreadyExists, RSEOperationNotSupported,
@@ -32,7 +32,6 @@ from rucio.common.exception import (RucioException, RSEWriteBlocked, DataIdentif
 from rucio.common.utils import (adler32, detect_client_location, execute, generate_uuid, make_valid_did, md5, send_trace,
                                 retry, GLOBALLY_SUPPORTED_CHECKSUMS)
 from rucio.rse import rsemanager as rsemgr
-from rucio import version
 
 
 class UploadClient:
@@ -68,7 +67,7 @@ class UploadClient:
         self.trace['eventType'] = 'upload'
         self.trace['eventVersion'] = version.RUCIO_VERSION[0]
 
-    def upload(self, items, summary_file_path=None, traces_copy_out=None, ignore_availability=False):
+    def upload(self, items, summary_file_path=None, traces_copy_out=None, ignore_availability=False, activity=None):
         """
         :param items: List of dictionaries. Each dictionary describing a file to upload. Keys:
             path                  - path of the file that will be uploaded
@@ -77,6 +76,7 @@ class UploadClient:
             did_name              - Optional: custom did name (Default: name of the file)
             dataset_scope         - Optional: custom dataset scope
             dataset_name          - Optional: custom dataset name
+            dataset_meta          - Optional: custom metadata for dataset
             impl                  - Optional: name of the protocol implementation to be used to upload this item.
             force_scheme          - Optional: force a specific scheme (if PFN upload this will be overwritten) (Default: None)
             pfn                   - Optional: use a given PFN (this sets no_register to True, and no_register becomes mandatory)
@@ -89,6 +89,7 @@ class UploadClient:
         :param summary_file_path: Optional: a path where a summary in form of a json file will be stored
         :param traces_copy_out: reference to an external list, where the traces should be uploaded
         :param ignore_availability: ignore the availability of a RSE
+        :param activity: the activity set to the rule if no dataset is specified
 
         :returns: 0 on success
 
@@ -196,7 +197,7 @@ class UploadClient:
             #    impl = self.preferred_impl(rse_settings, domain)
 
             if not no_register and not register_after_upload:
-                self._register_file(file, registered_dataset_dids, ignore_availability=ignore_availability)
+                self._register_file(file, registered_dataset_dids, ignore_availability=ignore_availability, activity=activity)
 
             # if register_after_upload, file should be overwritten if it is not registered
             # otherwise if file already exists on RSE we're done
@@ -286,7 +287,7 @@ class UploadClient:
 
                 if not no_register:
                     if register_after_upload:
-                        self._register_file(file, registered_dataset_dids, ignore_availability=ignore_availability)
+                        self._register_file(file, registered_dataset_dids, ignore_availability=ignore_availability, activity=activity)
                     else:
                         replica_for_api = self._convert_file_for_api(file)
                         try:
@@ -335,7 +336,7 @@ class UploadClient:
             raise NotAllFilesUploaded()
         return 0
 
-    def _register_file(self, file, registered_dataset_dids, ignore_availability=False):
+    def _register_file(self, file, registered_dataset_dids, ignore_availability=False, activity=None):
         """
         Registers the given file in Rucio. Creates a dataset if
         needed. Registers the file DID and creates the replication
@@ -345,6 +346,7 @@ class UploadClient:
         :param file: dictionary describing the file
         :param registered_dataset_dids: set of dataset dids that were already registered
         :param ignore_availability: ignore the availability of a RSE
+        :param activity: the activity set to the rule if no dataset is specified
 
         :raises DataIdentifierAlreadyExists: if file DID is already registered and the checksums do not match
         """
@@ -369,6 +371,7 @@ class UploadClient:
                 logger(logging.DEBUG, 'Trying to create dataset: %s' % dataset_did_str)
                 self.client.add_dataset(scope=file['dataset_scope'],
                                         name=file['dataset_name'],
+                                        meta=file.get('dataset_meta'),
                                         rules=[{'account': self.client.account,
                                                 'copies': 1,
                                                 'rse_expression': rse,
@@ -376,7 +379,11 @@ class UploadClient:
                                                 'lifetime': file.get('lifetime')}])
                 logger(logging.INFO, 'Successfully created dataset %s' % dataset_did_str)
             except DataIdentifierAlreadyExists:
-                logger(logging.DEBUG, 'Dataset %s already exists' % dataset_did_str)
+                logger(logging.INFO, 'Dataset %s already exists - no rule will be created' % dataset_did_str)
+
+                if file.get('lifetime') is not None:
+                    raise InputValidationError('Dataset %s exists and lifetime %s given. Prohibited to modify parent dataset lifetime.' % (dataset_did_str,
+                                                                                                                                           file.get('lifetime')))
         else:
             logger(logging.DEBUG, 'Skipping dataset registration')
 
@@ -406,7 +413,7 @@ class UploadClient:
             logger(logging.INFO, 'Successfully added replica in Rucio catalogue at %s' % rse)
             if not dataset_did_str:
                 # only need to add rules for files if no dataset is given
-                self.client.add_replication_rule([file_did], copies=1, rse_expression=rse, lifetime=file.get('lifetime'), ignore_availability=ignore_availability)
+                self.client.add_replication_rule([file_did], copies=1, rse_expression=rse, lifetime=file.get('lifetime'), ignore_availability=ignore_availability, activity=activity)
                 logger(logging.INFO, 'Successfully added replication rule at %s' % rse)
 
     def _get_file_guid(self, file):
