@@ -13,16 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import importlib
+from configparser import NoOptionError, NoSectionError
 from os import environ
 
-try:
-    from ConfigParser import NoOptionError, NoSectionError
-except ImportError:
-    from configparser import NoOptionError, NoSectionError
-
 from rucio.common import config, exception
-
-import importlib
+from rucio.common.utils import check_policy_package_version
 
 # dictionary of schema modules for each VO
 schema_modules = {}
@@ -44,9 +40,11 @@ if not multivo:
     if config.config_has_section('policy'):
         try:
             if 'RUCIO_POLICY_PACKAGE' in environ:
-                POLICY = environ['RUCIO_POLICY_PACKAGE'] + ".schema"
+                POLICY = environ['RUCIO_POLICY_PACKAGE']
             else:
-                POLICY = config.config_get('policy', 'package', check_config_table=False) + ".schema"
+                POLICY = config.config_get('policy', 'package', check_config_table=False)
+            check_policy_package_version(POLICY)
+            POLICY = POLICY + ".schema"
         except (NoOptionError, NoSectionError):
             # fall back to old system for now
             try:
@@ -72,9 +70,11 @@ def load_schema_for_vo(vo):
         try:
             env_name = 'RUCIO_POLICY_PACKAGE_' + vo.upper()
             if env_name in environ:
-                POLICY = environ[env_name] + ".schema"
+                POLICY = environ[env_name]
             else:
-                POLICY = config.config_get('policy', 'package-' + vo, check_config_table=False) + ".schema"
+                POLICY = config.config_get('policy', 'package-' + vo, check_config_table=False)
+            check_policy_package_version(POLICY)
+            POLICY = POLICY + ".schema"
         except (NoOptionError, NoSectionError):
             # fall back to old system for now
             try:
