@@ -15,20 +15,8 @@
 
 import os
 import re
-try:
-    # PY2
-    import urlparse
-except ImportError:
-    # PY3
-    import urllib.parse as urlparse
-
-try:
-    # PY2
-    from commands import getstatusoutput
-except ImportError:
-    # PY3
-    from subprocess import getstatusoutput
-from six import string_types
+import urllib.parse as urlparse
+from subprocess import getstatusoutput
 
 from rucio.common import exception
 from rucio.common.utils import execute
@@ -63,7 +51,7 @@ class Default(protocol.RSEProtocol):
         if '://' in hostname:
             hostname = hostname.split("://")[1]
 
-        lfns = [lfns] if type(lfns) == dict else lfns
+        lfns = [lfns] if isinstance(lfns, dict) else lfns
         if not self.attributes['port']:
             for lfn in lfns:
                 scope, name, path = lfn['scope'], lfn['name'], lfn.get('path')
@@ -97,7 +85,7 @@ class Default(protocol.RSEProtocol):
         """
 
         ret = dict()
-        pfns = [pfns] if isinstance(pfns, string_types) else pfns
+        pfns = [pfns] if isinstance(pfns, str) else pfns
         for pfn in pfns:
             parsed = urlparse.urlparse(pfn)
             if parsed.path.startswith('/srm/managerv2') or\
@@ -270,7 +258,7 @@ class Default(protocol.RSEProtocol):
         :raises SourceNotFound: if the source file was not found on the referred storage.
         """
 
-        pfns = [path] if isinstance(path, string_types) else path
+        pfns = [path] if isinstance(path, str) else path
 
         try:
             pfn_chunks = [pfns[i:i + 20] for i in range(0, len(pfns), 20)]
