@@ -110,7 +110,7 @@ class Default(protocol.RSEProtocol):
 
             if status_query == 0:
                 chsum = 'md5'
-                val = out.strip('  ').split()
+                val = out.strip(' ').split()
                 ret[chsum] = val[0]
 
         except Exception as e:
@@ -157,7 +157,7 @@ class Default(protocol.RSEProtocol):
         if not prefix.endswith('/'):
             prefix = ''.join([prefix, '/'])
 
-        lfns = [lfns] if type(lfns) == dict else lfns
+        lfns = [lfns] if isinstance(lfns, dict) else lfns
         for lfn in lfns:
             scope, name = lfn['scope'], lfn['name']
             if 'path' in lfn and lfn['path'] is not None:
@@ -324,7 +324,7 @@ class Rsync(Default):
 
             if status_query == 0:
                 chsum = 'md5'
-                val = out.strip('  ').split()
+                val = out.strip(' ').split()
                 ret[chsum] = val[0]
 
         except Exception as e:
