@@ -26,6 +26,7 @@ clients_requirements_table = {
         'dogpile.cache',
         'tabulate',
         'jsonschema',
+        'dataclasses',
     ],
     'ssh': ['paramiko'],
     'kerberos': [
@@ -35,10 +36,8 @@ clients_requirements_table = {
     ],
     'swift': ['python-swiftclient'],
     'argcomplete': ['argcomplete'],
-    'sftp': ['pysftp'],
-    # 'gfal2': ['gfal2-python'],
+    'sftp': ['paramiko'],
     'dumper': [
-        # 'gfal2-python',
         'python-magic',
     ],
 }
@@ -67,7 +66,6 @@ server_requirements_table = {
         'python-magic',
         'paramiko',
         'boto3',
-        'pysftp',
         'sqlalchemy',
         'alembic',
         'pymemcache',
@@ -76,7 +74,6 @@ server_requirements_table = {
         'statsd',
         'geoip2',
         'google-auth',
-        'retrying',
         'redis',
         'flask',
         'oic',
@@ -115,8 +112,9 @@ def run_shell_command(cmd):
 
 
 def get_rucio_version():
+    python_executable = "'" + sys.executable + "'"
     ver = run_shell_command(
-        "PYTHONPATH=lib " + sys.executable + " -c "
+        "PYTHONPATH=lib " + python_executable + " -c "
         '"from rucio import version; print(version.version_string())"'
     )
     if not ver:
